@@ -46,6 +46,7 @@
 #include <giomm/menu.h>
 
 #include <gtkmm/main.h>
+#include <gtkmm/textview.h>
 
 #include <giomm/file.h>
 #include <glibmm/spawn.h>
@@ -694,7 +695,7 @@ void AppWindow::open_browsed_document(const EpcServiceInfo* server, const Glib::
     }
 
     g_free(document_contents);
-    document_contents = 0;
+    document_contents = nullptr;
 
     //TODO_Performance: Horribly inefficient, but happens rarely:
     const auto temp_document_contents = document_temp.build_and_get_contents();
@@ -2104,8 +2105,7 @@ Glib::ustring AppWindow::ui_file_select_save(const Glib::ustring& old_file_uri)
 
   fileChooser_Save->set_do_overwrite_confirmation(); //Ask the user if the file already exists.
 
-  auto pWindow = dynamic_cast<Gtk::Window*>(&app);
-  if(pWindow)
+  if(auto pWindow = dynamic_cast<Gtk::Window*>(&app))
     fileChooser_Save->set_transient_for(*pWindow);
 
   fileChooser_Save->add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
@@ -2692,7 +2692,7 @@ Glib::ustring AppWindow::get_current_locale()
     return m_current_locale;
 
   //Get the user's current locale:
-  const auto cLocale = setlocale(LC_ALL, 0); //Passing NULL means query, instead of set.
+  const auto cLocale = setlocale(LC_ALL, nullptr); //Passing NULL means query, instead of set.
   if(cLocale)
   {
     //std::cout << "debug1: " << G_STRFUNC << ": locale=" << cLocale << std::endl;
@@ -2874,9 +2874,8 @@ void AppWindow::document_history_remove(const Glib::ustring& file_uri)
 void AppWindow::on_menu_edit_copy_activate()
 {
   auto widget = get_focus();
-  auto editable = dynamic_cast<Gtk::Editable*>(widget);
 
-  if(editable)
+  if(auto editable = dynamic_cast<Gtk::Editable*>(widget))
   {
     editable->copy_clipboard();
     return;
@@ -2884,11 +2883,9 @@ void AppWindow::on_menu_edit_copy_activate()
 
   //GtkTextView does not implement GtkEditable.
   //See GTK+ bug: https://bugzilla.gnome.org/show_bug.cgi?id=667008
-  auto textview = dynamic_cast<Gtk::TextView*>(widget);
-  if(textview)
+  if(auto textview = dynamic_cast<Gtk::TextView*>(widget))
   {
-    auto buffer = textview->get_buffer();
-    if(buffer)
+    if(auto buffer = textview->get_buffer())
     {
       auto clipboard =
         Gtk::Clipboard::get_for_display(get_display());
@@ -2900,9 +2897,8 @@ void AppWindow::on_menu_edit_copy_activate()
 void AppWindow::on_menu_edit_cut_activate()
 {
   auto widget = get_focus();
-  auto editable = dynamic_cast<Gtk::Editable*>(widget);
 
-  if(editable)
+  if(auto editable = dynamic_cast<Gtk::Editable*>(widget))
   {
     editable->cut_clipboard();
     return;
@@ -2910,8 +2906,7 @@ void AppWindow::on_menu_edit_cut_activate()
 
   //GtkTextView does not implement GtkEditable.
   //See GTK+ bug: https://bugzilla.gnome.org/show_bug.cgi?id=667008
-  auto textview = dynamic_cast<Gtk::TextView*>(widget);
-  if(textview)
+  if(auto textview = dynamic_cast<Gtk::TextView*>(widget))
   {
     auto buffer = textview->get_buffer();
     if(buffer)
@@ -2926,9 +2921,8 @@ void AppWindow::on_menu_edit_cut_activate()
 void AppWindow::on_menu_edit_paste_activate()
 {
   auto widget = get_focus();
-  auto editable = dynamic_cast<Gtk::Editable*>(widget);
 
-  if(editable)
+  if(auto editable = dynamic_cast<Gtk::Editable*>(widget))
   {
     editable->paste_clipboard();
     return;
@@ -2936,8 +2930,7 @@ void AppWindow::on_menu_edit_paste_activate()
 
   //GtkTextView does not implement GtkEditable.
   //See GTK+ bug: https://bugzilla.gnome.org/show_bug.cgi?id=667008
-  auto textview = dynamic_cast<Gtk::TextView*>(widget);
-  if(textview)
+  if(auto textview = dynamic_cast<Gtk::TextView*>(widget))
   {
     auto buffer = textview->get_buffer();
     if(buffer)
