@@ -21,7 +21,7 @@
 
 #include <gtkmm/window.h>
 #include <gdkmm/cursor.h>
-#include <map>
+#include <unordered_map>
 
 namespace Glom
 {
@@ -50,7 +50,7 @@ private:
   Gtk::Window* m_window;
   Glib::RefPtr<Gdk::Window> m_gdk_window;
 
-  typedef std::map<Gtk::Window*, Glib::RefPtr<Gdk::Cursor> > type_map_cursors;
+  typedef std::unordered_map<Gtk::Window*, Glib::RefPtr<Gdk::Cursor> > type_map_cursors;
   static type_map_cursors m_map_cursors;
   Glib::RefPtr<Gdk::Cursor> m_old_cursor;
 };
