@@ -861,8 +861,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
   }
 
   //Update the UI:
-  auto pApp = dynamic_cast<AppWindow*>(get_app_window());
-  if(pApp)
+  if(auto pApp = dynamic_cast<AppWindow*>(get_app_window()))
   {
     pApp->update_network_shared_ui();
   }
@@ -1145,8 +1144,7 @@ Gtk::Window* Frame_Glom::get_app_window()
   while(pWidget)
   {
     //Is this widget a Gtk::Window?:
-    auto pWindow = dynamic_cast<Gtk::Window*>(pWidget);
-    if(pWindow)
+    if(auto pWindow = dynamic_cast<Gtk::Window*>(pWidget))
     {
       //Yes, return it.
       return pWindow;
@@ -1226,7 +1224,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
     records_found = (update_records_count() > 0);
 
     if(!inited)
-      records_found = 0;
+      records_found = false;
   }
 
   std::cout << G_STRFUNC << ": records_found=" << records_found << std::endl;
@@ -1287,7 +1285,7 @@ void Frame_Glom::update_table_in_document_from_database()
   //TODO_performance: There are a lot of temporary Field and Column instances here, with a lot of string copying.
 
   //For instance, changed field details, or new fields, or removed fields.
-  typedef Box_DB_Table::type_vec_fields type_vec_fields;
+  using type_vec_fields = Box_DB_Table::type_vec_fields;
 
   //Get the fields information from the database:
   DbUtils::type_vec_fields fieldsDatabase = DbUtils::get_fields_for_table_from_database(m_table_name);
@@ -1426,7 +1424,7 @@ void Frame_Glom::on_menu_developer_fields()
 
 }
 
-void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent, const Glib::ustring table_name)
+void Frame_Glom::do_menu_developer_fields(Gtk::Window& parent, const Glib::ustring& table_name)
 {
   if(!m_dialog_fields)
   {
@@ -1489,7 +1487,7 @@ void Frame_Glom::on_menu_developer_relationships_overview()
   }
 }
 
-void Frame_Glom::do_menu_developer_relationships(Gtk::Window& parent, const Glib::ustring table_name)
+void Frame_Glom::do_menu_developer_relationships(Gtk::Window& parent, const Glib::ustring& table_name)
 {
   //Create the widget if necessary:
   if(!m_dialog_relationships)
@@ -2082,7 +2080,7 @@ bool Frame_Glom::handle_request_password_connection_error(bool asked_for_passwor
   }
 }
 
-bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_found, const Glib::ustring known_username, const Glib::ustring& known_password, bool confirm_known_user)
+bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_found, const Glib::ustring& known_username, const Glib::ustring& known_password, bool confirm_known_user)
 {
   //Initialize output parameter:
   database_not_found = false;
@@ -2355,8 +2353,7 @@ void Frame_Glom::on_dialog_tables_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
     if(document->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
-      auto pApp = dynamic_cast<AppWindow*>(get_app_window());
-      if(pApp)
+      if(auto pApp = dynamic_cast<AppWindow*>(get_app_window()))
         pApp->fill_menu_tables();
 
       //Select a different table if the current one no longer exists:
