@@ -20,10 +20,8 @@
 
 #include "dialog_import_csv.h"
 #include <glom/import_csv/file_encodings.h>
-#include <libglom/libglom_config.h>
-
+#include <libglom/utils.h>
 #include <libglom/data_structure/glomconversions.h>
-
 #include <gtkmm/messagedialog.h>
 #include <gtkmm/cellrenderercombo.h>
 #include <glom/utils_ui.h>
@@ -70,7 +68,7 @@ const bool Dialog_Import_CSV::glade_developer(false);
 Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   m_auto_detect_encoding(),
-  m_cols_count(-1)
+  m_cols_count(0)
 {
   builder->get_widget("import_csv_fields", m_sample_view);
   builder->get_widget("import_csv_target_table", m_target_table);
@@ -379,8 +377,8 @@ void Dialog_Import_CSV::on_sample_rows_changed()
     return;
 
   const auto children_size = m_sample_model->children().size();
-  const guint current_sample_rows = (children_size == 0 ? 0 : children_size - 1);
-  const guint new_sample_rows = m_sample_rows->get_value_as_int();
+  const auto current_sample_rows = (children_size == 0 ? 0 : children_size - 1);
+  const guint new_sample_rows = std::max(0, m_sample_rows->get_value_as_int());
 
   if(current_sample_rows > new_sample_rows)
   {
@@ -395,7 +393,7 @@ void Dialog_Import_CSV::on_sample_rows_changed()
   else
   {
     // Find index of first row to add
-    guint row_index = current_sample_rows;
+    auto row_index = current_sample_rows;
     if(m_first_line_as_title->get_active())
       ++row_index;
 
@@ -572,7 +570,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 
   if(row == -1)
   {
-    std::shared_ptr<Field> field = m_fields[column_number];
+    const auto field = m_fields[column_number];
     if(field)
       text = field->get_name();
     else
@@ -587,7 +585,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 
     if(column_number < m_fields.size())
     {
-      std::shared_ptr<Field> field = m_fields[column_number];
+      const auto field = m_fields[column_number];
 
       if(row != -1) // && static_cast<unsigned int>(row) < m_parser->get_rows_count())
       {
@@ -650,7 +648,7 @@ void Dialog_Import_CSV::on_field_edited(const Glib::ustring& path, const Glib::u
   {
     if( (elem)[m_field_columns.m_col_field_name] == new_text)
     {
-      std::shared_ptr<Field> field = (elem)[m_field_columns.m_col_field];
+      const std::shared_ptr<Field> field = (elem)[m_field_columns.m_col_field];
       // Check whether another column is already using that field
       auto vec_field_iter = Utils::find(m_fields, field);
       // Reset the old column since two different columns cannot be imported into the same field
