@@ -84,12 +84,12 @@ public:
   //This are public for use by std::make_shared<>().
   //TODO: Does this need to be virtual?
   ConnectionPool();
-  virtual ~ConnectionPool();
+  virtual ~ConnectionPool() = default;
 
   ConnectionPool(const ConnectionPool& src) = delete;
-  ConnectionPool(ConnectionPool&& src) = delete;
+  ConnectionPool(ConnectionPool&& src) = default;
   ConnectionPool& operator=(const ConnectionPool& src) = delete;
-  ConnectionPool& operator=(ConnectionPool&& src) = delete;
+  ConnectionPool& operator=(ConnectionPool&& src) = default;
 
   typedef ConnectionPoolBackends::Backend Backend;
   typedef Backend::type_vec_const_fields type_vec_const_fields;
