@@ -39,7 +39,7 @@
 #else
 # include <sys/types.h>
 # include <sys/socket.h>
-# include <errno.h>
+# include <cerrno>
 # include <netinet/in.h> //For sockaddr_in
 #endif
 
