@@ -51,35 +51,6 @@ Field::Field()
   m_translatable_item_type = enumTranslatableItemType::FIELD;
 }
 
-Field::Field(const Field& src)
-: TranslatableItem(src)
-{
-  //TODO_Performance: Implement this properly, without the extra copy.
-  operator=(src);
-}
-
-Field& Field::operator=(const Field& src)
-{
-  TranslatableItem::operator=(src);
-
-  m_glom_type = src.m_glom_type;
-  m_field_info = src.m_field_info->copy();
-
-  m_lookup_relationship = src.m_lookup_relationship;
-  m_strLookupField = src.m_strLookupField;
-
-  m_calculation = src.m_calculation;
-
-  m_visible = src.m_visible;
-
-  m_primary_key = src.m_primary_key;
-  m_unique_key = src.m_unique_key;
-
-  m_default_formatting = src.m_default_formatting;
-
-  return *this;
-}
-
 bool Field::operator==(const Field& src) const
 {
   return TranslatableItem::operator==(src)
@@ -585,7 +556,7 @@ Field::glom_field_type Field::get_glom_type_for_gda_type(GType gda_type)
 {
   init_map();
 
-  Field::glom_field_type result = glom_field_type::INVALID;
+  auto result = glom_field_type::INVALID;
 
   //Get the glom type used for this gda type:
   {
@@ -788,7 +759,7 @@ Glib::ustring Field::get_type_name_ui(glom_field_type glom_type)
 //static:
 Field::glom_field_type Field::get_type_for_ui_name(const Glib::ustring& glom_type)
 {
-  glom_field_type result = glom_field_type::INVALID;
+  auto result = glom_field_type::INVALID;
 
   for(const auto& the_pair : m_map_type_names_ui)
   {
