@@ -32,7 +32,7 @@
 #include <ctime>     // for struct tm
 #include <iostream>   // for cout, endl
 #include <iomanip>
-#include <string.h> // for strlen, memset, strcmp
+#include <cstring> // for strlen, memset, strcmp
 
 #include <glibmm/i18n-lib.h>
 
@@ -103,7 +103,7 @@ static inline const char* glom_get_locale_date_format()
     //each time.
     //Even when the LC_TIME environment variable is not set, we still seem
     //to get a useful value here, based on LC_ALL, for instance.
-    char* lc_time = setlocale(LC_TIME, NULL);
+    char* lc_time = setlocale(LC_TIME, nullptr);
     if(lc_time)
       lc_time = g_strdup(lc_time);
 
@@ -121,7 +121,7 @@ static inline const char* glom_get_locale_date_format()
       //(which uses 2 digits when using %x).
 
       //Get the current LC_MESSAGES value:
-      old_lc_messages = g_strdup(setlocale(LC_MESSAGES, NULL));
+      old_lc_messages = g_strdup(setlocale(LC_MESSAGES, nullptr));
       if(old_lc_messages)
         old_lc_messages = g_strdup(old_lc_messages);
 
@@ -263,12 +263,11 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
   //http://www.roguewave.com/support/docs/sourcepro/stdlibref/time-put.html
 
   //Format it into this stream:
-  typedef std::stringstream type_stream;
-  type_stream the_stream;
+  std::stringstream the_stream;
   the_stream.imbue(locale); //Make it format things for this locale. (Actually, I don't know if this is necessary, because we mention the locale in the time_put<> constructor.
 
   // Get a time_put face:
-  typedef std::time_put<char> type_time_put;
+  using type_time_put = std::time_put<char>;
   const auto& tp = std::use_facet<type_time_put>(locale);
 
   //type_iterator begin(the_stream);
@@ -691,7 +690,7 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
   else if(glom_type == Field::glom_field_type::BOOLEAN)
   {
     success = true;
-    return Gnome::Gda::Value( (text.uppercase() == "TRUE" ? true : false) ); //TODO: Internationalize this, but it should never be used anyway.
+    return Gnome::Gda::Value(text.uppercase() == "TRUE"); //TODO: Internationalize this, but it should never be used anyway.
   }
   else if(glom_type == Field::glom_field_type::IMAGE)
   {
@@ -731,7 +730,7 @@ tm Conversions::parse_date(const Glib::ustring& text, const std::locale& locale,
   //http://www.roguewave.com/support/docs/sourcepro/stdlibref/time-get.html
 
   //Format it into this stream:
-  typedef std::stringstream type_stream;
+  using type_stream = std::stringstream;
 
 
   //tm the_c_time = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
@@ -761,8 +760,8 @@ tm Conversions::parse_date(const Glib::ustring& text, const std::locale& locale,
 
     // Get a time_get facet:
 
-    typedef std::time_get<char> type_time_get;
-    typedef type_time_get::iter_type type_iterator;
+    using type_time_get = std::time_get<char>;
+    using type_iterator = type_time_get::iter_type;
 
     const auto& tg = std::use_facet<type_time_get>(locale);
 
@@ -878,7 +877,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   //http://www.roguewave.com/support/docs/sourcepro/stdlibref/time-get.html
 
   //Format it into this stream:
-  typedef std::stringstream type_stream;
+  using type_stream = std::stringstream;
 
    //tm the_c_time = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
