@@ -27,12 +27,6 @@ LayoutItem_WithFormatting::LayoutItem_WithFormatting()
 {
 }
 
-LayoutItem_WithFormatting::LayoutItem_WithFormatting(const LayoutItem_WithFormatting& src)
-: LayoutItem(src),
-  m_formatting(src.m_formatting)
-{
-}
-
 bool LayoutItem_WithFormatting::operator==(const LayoutItem_WithFormatting& src) const
 {
   auto result = LayoutItem::operator==(src) &&
@@ -41,16 +35,6 @@ bool LayoutItem_WithFormatting::operator==(const LayoutItem_WithFormatting& src)
   return result;
 }
 
-//Avoid using this, for performance:
-LayoutItem_WithFormatting& LayoutItem_WithFormatting::operator=(const LayoutItem_WithFormatting& src)
-{
-  LayoutItem::operator=(src);
-
-  m_formatting = src.m_formatting;
-
-  return *this;
-}
-
 const Formatting& LayoutItem_WithFormatting::get_formatting_used() const
 {
   return m_formatting;
@@ -58,7 +42,7 @@ const Formatting& LayoutItem_WithFormatting::get_formatting_used() const
 
 Formatting::HorizontalAlignment LayoutItem_WithFormatting::get_formatting_used_horizontal_alignment(bool /* for_details_view */) const
 {
-  const auto format = get_formatting_used();
+  const auto& format = get_formatting_used();
   Formatting::HorizontalAlignment alignment =
     format.get_horizontal_alignment();
 
