@@ -29,24 +29,11 @@ LayoutItem_VerticalGroup::LayoutItem_VerticalGroup()
 {
 }
 
-LayoutItem_VerticalGroup::LayoutItem_VerticalGroup(const LayoutItem_VerticalGroup& src)
-: LayoutGroup(src)
-{
-}
-
 LayoutItem* LayoutItem_VerticalGroup::clone() const
 {
   return new LayoutItem_VerticalGroup(*this);
 }
 
-
-LayoutItem_VerticalGroup& LayoutItem_VerticalGroup::operator=(const LayoutItem_VerticalGroup& src)
-{
-  LayoutGroup::operator=(src);
-
-  return *this;
-}
-
 Glib::ustring LayoutItem_VerticalGroup::get_part_type_name() const
 {
   //Translators: This is the name of a UI element (a layout part name).
