@@ -28,11 +28,6 @@ StaticText::StaticText()
   m_translatable_item_type = enumTranslatableItemType::STATIC_TEXT;
 }
 
-StaticText::StaticText(const StaticText& src)
-: TranslatableItem(src)
-{
-}
-
 bool StaticText::operator==(const StaticText& src) const
 {
   const auto result = TranslatableItem::operator==(src);
@@ -40,11 +35,4 @@ bool StaticText::operator==(const StaticText& src) const
   return result;
 }
 
-//Avoid using this, for performance:
-StaticText& StaticText::operator=(const StaticText& src)
-{
-  TranslatableItem::operator=(src);
-  return *this;
-}
-
 } //namespace Glom
