@@ -42,10 +42,6 @@ PyGlomRecord::PyGlomRecord()
 {
 }
 
-PyGlomRecord::~PyGlomRecord()
-{
-}
-
 void PyGlomRecord::set_read_only()
 {
   m_read_only = true;
@@ -145,7 +141,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
      return;
   }
 
-  const Field::glom_field_type field_type = field->get_glom_type(); //TODO
+  const auto field_type = field->get_glom_type(); //TODO
 
   Gnome::Gda::Value field_value;
   GValue value_c = {0, {{0}}};
@@ -224,7 +220,7 @@ void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_v
   m_key_field = key_field;
   m_key_field_value = key_field_value;
 
-  if(m_document == 0)
+  if(m_document == nullptr)
     m_document = document;
 
   m_connection = opened_connection;
