@@ -31,10 +31,6 @@
 namespace Glom
 {
 
-///field, ascending
-typedef std::pair< std::shared_ptr<const LayoutItem_Field>, bool> type_pair_sort_field;
-typedef std::vector<type_pair_sort_field> type_sort_clause;
-
 namespace GlomXslUtils
 {
 
