@@ -80,7 +80,7 @@ public:
    */
   //Should be a MI class, derived by those sub-classes. TODO.
   //where_clause.
-  sigc::signal<void, Gnome::Gda::SqlExpr> signal_find_criteria;
+  sigc::signal<void(Gnome::Gda::SqlExpr)> signal_find_criteria;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //g++ 3.4 needs this to be public when used from Box_Data_Details. I'm not sure why. murrayc.
