@@ -33,24 +33,22 @@ class Box_Data_List_Related : public Box_Data_Portal
 public:
   Box_Data_List_Related();
 
-  /**
-   * @param portal: The full portal details
-   */
-  bool init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title = true) override;
+  bool init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title) override;
 
   /** Use this if no portal is yet defined, so the user can use the context menu to define a portal.
    */
-  bool init_db_details(const Glib::ustring& parent_table, bool show_title = true) override;
+  bool init_db_details_without_portal(const Glib::ustring &parent_table) override;
 
   void set_find_mode(bool val = true) override;
 
 protected:
   bool fill_from_database() override;
 
+  void show_title_in_ui(const Glib::ustring& title) override;
+
   //Signal handlers:
   void on_adddel_record_changed();
   void on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row);
-  void on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd);
 
   void on_adddel_script_button_clicked(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row);
   bool on_script_button_idle(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key);
