@@ -142,7 +142,7 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
   }
 }
 
-void ComboGlom::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboGlom::set_choices_related(const std::shared_ptr<const Document>& document, const LayoutItem_Field& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   ComboChoicesWithTreeModel::set_choices_related(document, layout_field, foreign_key_value);
 
@@ -271,7 +271,7 @@ void ComboGlom::set_value(const Gnome::Gda::Value& value)
       return;
 
     const Glib::ustring fg_color =
-    layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
+      layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
     if(fg_color.empty())
     {
       //GtkComboBox doesn't interpret "" as an unset. TODO: Fix that?
@@ -320,11 +320,11 @@ g_warning("ComboGlom::on_button_press_event()");
     if(pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_menu_popup->popup(button_event->button, button_event->time);
+        m_menu_popup->popup_at_pointer((GdkEvent*)button_event);
         return true; //We handled this event.
       }
     }
