@@ -52,7 +52,7 @@ public:
 
   void set_choices_fixed(const Formatting::type_list_values& list_values, bool restricted = false) override;
 
-  void set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value) override;
+  void set_choices_related(const std::shared_ptr<const Document>& document, const LayoutItem_Field& layout_field, const Gnome::Gda::Value& foreign_key_value) override;
 
   void set_read_only(bool read_only = true) override;
 
@@ -92,8 +92,7 @@ private:
 
   Glib::ustring m_old_text;
 
-  typedef std::map<Glib::ustring, Gtk::RadioButton*> type_map_buttons;
-  type_map_buttons m_map_buttons;
+  std::unordered_map<Glib::ustring, Gtk::RadioButton*, std::hash<std::string>> m_map_buttons;
 };
 
 } //namespace DataWidetChildren
