@@ -118,7 +118,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
   //Fill the model with data:
   auto layout_item =
     std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
-  const auto format = layout_item->get_formatting_used();
+  const auto& format = layout_item->get_formatting_used();
   std::shared_ptr<const Relationship> choice_relationship;
   std::shared_ptr<const LayoutItem_Field> layout_choice_first;
   std::shared_ptr<const LayoutGroup> layout_choice_extra;
@@ -229,7 +229,7 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const Formatting::type_list_va
   //then sets up the view, using the model.
 }
 
-void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const Document>& document, const LayoutItem_Field& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   if(!document)
   {
@@ -237,7 +237,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const
     return;
   }
 
-  const auto format = layout_field->get_formatting_used();
+  const auto& format = layout_field.get_formatting_used();
   std::shared_ptr<const Relationship> choice_relationship;
   std::shared_ptr<const LayoutItem_Field> layout_choice_first;
   std::shared_ptr<const LayoutGroup> layout_choice_extra;
@@ -327,8 +327,7 @@ void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell
     }
     case(Field::glom_field_type::IMAGE):
     {
-      auto pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell);
-      if(pDerived)
+      if(auto pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(cell))
       {
         const auto pixbuf = UiUtils::get_pixbuf_for_gda_value(value);
 
@@ -345,28 +344,28 @@ void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell
     default:
     {
       //TODO: Maybe we should have custom cellcells for time, date, and numbers.
-      auto pDerived = dynamic_cast<Gtk::CellRendererText*>(cell);
-      if(pDerived)
+      if(auto pDerived = dynamic_cast<Gtk::CellRendererText*>(cell))
       {
         //std::cout << "debug: " << G_STRFUNC << ": field name=" << field->get_name() << ", glom type=" << field->get_glom_type() << std::endl;
         const auto text = Conversions::get_text_for_gda_value(field->get_glom_type(), value, field->get_formatting_used().m_numeric_format);
         pDerived->property_text() = text;
+
+        //Show a different color if the value is numeric, if that's specified:
+        if(type == Field::glom_field_type::NUMERIC)
+        {
+          const Glib::ustring fg_color =
+            field->get_formatting_used().get_text_format_color_foreground_to_use(value);
+          if(!fg_color.empty())
+            pDerived->property_foreground() = fg_color;
+          else
+            pDerived->property_foreground().reset_value();
+        }
       }
       else
       {
          std::cerr << G_STRFUNC << ": cell has an unexpected type: " << typeid(cell).name() << std::endl;
       }
 
-      //Show a different color if the value is numeric, if that's specified:
-      if(type == Field::glom_field_type::NUMERIC)
-      {
-        const Glib::ustring fg_color =
-        field->get_formatting_used().get_text_format_color_foreground_to_use(value);
-        if(!fg_color.empty())
-          pDerived->property_foreground() = fg_color;
-        else
-          pDerived->property_foreground().reset_value();
-      }
 
       break;
     }
@@ -439,7 +438,7 @@ int ComboChoicesWithTreeModel::get_fixed_cell_height(Gtk::Widget& widget)
       const auto item_withformatting = std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(item);
       if(item_withformatting)
       {
-         const auto formatting = item_withformatting->get_formatting_used();
+         const auto& formatting = item_withformatting->get_formatting_used();
          font_name = formatting.get_text_format_font();
       }
 
