@@ -73,7 +73,7 @@ DataWidget::DataWidget(const std::shared_ptr<LayoutItem_Field>& field, const Gli
   //http://library.gnome.org/devel/hig-book/stable/design-text-labels.html.en
   const auto title = Glib::ustring::compose(_("%1:"), item_get_title_or_name(field));
 
-  m_child = 0;
+  m_child = nullptr;
   LayoutWidgetField* pFieldWidget = nullptr;
   if(glom_type == Field::glom_field_type::BOOLEAN)
   {
@@ -132,7 +132,7 @@ DataWidget::DataWidget(const std::shared_ptr<LayoutItem_Field>& field, const Gli
         combo = create_combo_widget_for_field(field);
         combo->set_layout_item( get_layout_item(), table_name);
 
-        combo->set_choices_related(document, field, Gnome::Gda::Value() /* no ID means show all related records */);
+        combo->set_choices_related(document, *field, Gnome::Gda::Value() /* no ID means show all related records */);
       }
       else
       {
@@ -179,7 +179,7 @@ DataWidget::DataWidget(const std::shared_ptr<LayoutItem_Field>& field, const Gli
   if(m_child)
   {
     //Use the text formatting:
-    apply_formatting(*m_child, field);
+    apply_formatting(*m_child, *field);
 
     bool child_added = false; //Don't use an extra container unless necessary.
 
@@ -439,11 +439,11 @@ bool DataWidget::on_button_press_event(GdkEventButton *button_event)
     if(pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_menu_popup->popup(button_event->button, button_event->time);
+        m_menu_popup->popup_at_pointer((GdkEvent*)button_event);
         return true; //We handled this event.
       }
     }
