@@ -149,7 +149,7 @@ void Entry::set_value(const Gnome::Gda::Value& value)
   if(layout_item->get_glom_type() == Field::glom_field_type::NUMERIC)
   {
     const Glib::ustring fg_color =
-    layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
+      layout_item->get_formatting_used().get_text_format_color_foreground_to_use(value);
     if(!fg_color.empty())
     {
       UiUtils::load_color_into_css_provider(*this, fg_color);
@@ -197,11 +197,11 @@ bool Entry::on_button_press_event(GdkEventButton *button_event)
     if(pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_menu_popup->popup(button_event->button, button_event->time);
+        m_menu_popup->popup_at_pointer((GdkEvent*)button_event);
         return true; //We handled this event.
       }
     }
