@@ -294,11 +294,11 @@ bool DbAddDel::on_button_press_event_Popup(GdkEventButton *button_event)
 #endif
 
   GdkModifierType mods;
-  gdk_window_get_device_position( gtk_widget_get_window(Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window(Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
   if(mods & GDK_BUTTON3_MASK)
   {
     //Give user choices of actions on this item:
-    m_menu_popup->popup(button_event->button, button_event->time);
+    m_menu_popup->popup_at_pointer((GdkEvent*)button_event);
     return true; //handled.
   }
   else
@@ -326,7 +326,7 @@ Gtk::TreeModel::iterator DbAddDel::get_item_placeholder()
    return Gtk::TreeModel::iterator();
 }
 
-Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const LayoutItem_Field>& layout_item) const
+Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, const LayoutItem_Field& layout_item) const
 {
   Gnome::Gda::Value value;
 
@@ -361,7 +361,7 @@ Gnome::Gda::Value DbAddDel::get_value_key_selected() const
     return Gnome::Gda::Value();
 }
 
-Gnome::Gda::Value DbAddDel::get_value_selected(const std::shared_ptr<const LayoutItem_Field>& layout_item) const
+Gnome::Gda::Value DbAddDel::get_value_selected(const LayoutItem_Field& layout_item) const
 {
   return get_value(get_item_selected(), layout_item);
 }
@@ -425,10 +425,14 @@ bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, bool start_edit
       break;
   }
 
-  return select_item(iter, layout_item, start_editing);
+  if (!layout_item) {
+    return false;
+  }
+
+  return select_item(iter, *layout_item, start_editing);
 }
 
-bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const LayoutItem>& layout_item, bool start_editing)
+bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, const LayoutItem& layout_item, bool start_editing)
 {
   if(!m_list_store)
     return false;
@@ -548,7 +552,7 @@ guint DbAddDel::get_fixed_cell_height()
   //We get this style property, which might be causing it. murrayc
   //TODO: Find out if this is reallyt the right way to calculate the correct height:
   int extra_height = 0;
-  gtk_widget_style_get(GTK_WIDGET(m_tree_view.gobj()), "vertical-separator", &extra_height, (void*)0);
+  gtk_widget_style_get(GTK_WIDGET(m_tree_view.gobj()), "vertical-separator", &extra_height, (void*)nullptr);
   //std::cout << "debug: extra_height=" << extra_height << std::endl;
 
   return m_fixed_cell_height + extra_height;
@@ -566,8 +570,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const std:
   //Set extra cellrenderer attributes, depending on the type used,
   //to support editing:
 
-  auto pCellRendererText = dynamic_cast<Gtk::CellRendererText*>(pCellRenderer);
-  if(pCellRendererText)
+  if(auto pCellRendererText = dynamic_cast<Gtk::CellRendererText*>(pCellRenderer))
   {
     //Connect to edited signal:
     if(item_field) //Only fields can be edited:
@@ -584,8 +587,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const std:
   }
   else
   {
-    auto pCellRendererToggle = dynamic_cast<Gtk::CellRendererToggle*>(pCellRenderer);
-    if(pCellRendererToggle)
+    if(auto pCellRendererToggle = dynamic_cast<Gtk::CellRendererToggle*>(pCellRenderer))
     {
       pCellRendererToggle->property_activatable() = true;
 
@@ -596,14 +598,15 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const std:
           sigc::bind( sigc::mem_fun(*this, &DbAddDel::on_treeview_cell_edited_bool), model_column_index, data_model_column_index ) );
       }
     }
+    /*
     else
     {
-      auto pCellRendererPixbuf = dynamic_cast<Gtk::CellRendererPixbuf*>(pCellRenderer);
-      if(pCellRendererPixbuf)
+      if(auto pCellRendererPixbuf = dynamic_cast<Gtk::CellRendererPixbuf*>(pCellRenderer))
       {
         //TODO: Do something when it's clicked, such as show the big image in a window or tooltip?
       }
     }
+    */
   }
 
   auto pCellButton = Gtk::manage( new GlomCellRenderer_ButtonText() );
@@ -805,12 +808,12 @@ bool DbAddDel::refresh_from_database_blank()
   return true;
 }
 
-void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const LayoutItem_Field>& layout_item, const Gnome::Gda::Value& value)
+void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const LayoutItem_Field& layout_item, const Gnome::Gda::Value& value)
 {
   set_value(iter, layout_item, value, true /* including the specified field */);
 }
 
-void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const LayoutItem_Field>& layout_item, const Gnome::Gda::Value& value, bool set_specified_field_layout)
+void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const LayoutItem_Field& layout_item, const Gnome::Gda::Value& value, bool set_specified_field_layout)
 {
   //g_warning("DbAddDel::set_value begin");
 
@@ -847,7 +850,7 @@ void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const std::shared
   //g_warning("DbAddDel::set_value end");
 }
 
-void DbAddDel::set_value_selected(const std::shared_ptr<const LayoutItem_Field>& layout_item, const Gnome::Gda::Value& value)
+void DbAddDel::set_value_selected(const LayoutItem_Field& layout_item, const Gnome::Gda::Value& value)
 {
   set_value(get_item_selected(), layout_item, value);
 }
@@ -884,7 +887,7 @@ void DbAddDel::refresh_cell_choices_data_from_database_with_foreign_key(guint mo
     return;
   }
 
-  cell->set_choices_related(get_document(), layout_field, foreign_key_value);
+  cell->set_choices_related(get_document(), *layout_field, foreign_key_value);
 }
 
 void DbAddDel::remove_all_columns()
@@ -940,15 +943,12 @@ FoundSet DbAddDel::get_found_set() const
   return m_found_set;
 }
 
-DbAddDel::type_list_indexes DbAddDel::get_data_model_column_index(const std::shared_ptr<const LayoutItem_Field>& layout_item_field, bool including_specified_field_layout) const
+DbAddDel::type_list_indexes DbAddDel::get_data_model_column_index(const LayoutItem_Field& layout_item_field, bool including_specified_field_layout) const
 {
   //TODO_Performance: Replace all this looping by a cache/map:
 
   type_list_indexes list_indexes;
 
-  if(!layout_item_field)
-    return list_indexes;
-
   guint data_model_column_index = 0;
   for(const auto& item : m_column_items)
   {
@@ -956,7 +956,7 @@ DbAddDel::type_list_indexes DbAddDel::get_data_model_column_index(const std::sha
     if(field)
     {
       if(field->is_same_field(layout_item_field)
-        && (including_specified_field_layout || field != layout_item_field))
+        && (including_specified_field_layout || *field != layout_item_field))
       {
         list_indexes.emplace_back(data_model_column_index);
       }
@@ -968,29 +968,23 @@ DbAddDel::type_list_indexes DbAddDel::get_data_model_column_index(const std::sha
   return list_indexes;
 }
 
-DbAddDel::type_list_indexes DbAddDel::get_column_index(const std::shared_ptr<const LayoutItem>& layout_item) const
+DbAddDel::type_list_indexes DbAddDel::get_column_index(const LayoutItem& layout_item) const
 {
   //TODO_Performance: Replace all this looping by a cache/map:
 
   type_list_indexes list_indexes;
 
-  if(!layout_item)
-  {
-    std::cerr << G_STRFUNC << ": layout_item was null.\n";
-    return list_indexes;
-  }
-
-  auto layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  auto layout_item_field = dynamic_cast<const LayoutItem_Field*>(&layout_item);
 
   guint i = 0;
   for(const auto& item : m_column_items)
   {
     const auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(item); //TODO_Performance: This would be unnecessary if !layout_item_field
-    if(field && layout_item_field && field->is_same_field(layout_item_field))
+    if(field && layout_item_field && field->is_same_field(*layout_item_field))
     {
       list_indexes.emplace_back(i);
     }
-    else if(*(item) == *(layout_item))
+    else if(*(item) == layout_item)
     {
       list_indexes.emplace_back(i);
     }
@@ -1001,14 +995,11 @@ DbAddDel::type_list_indexes DbAddDel::get_column_index(const std::shared_ptr<con
   return list_indexes;
 }
 
-DbAddDel::type_list_indexes DbAddDel::get_choice_index(const std::shared_ptr<const LayoutItem_Field>& from_key)
+DbAddDel::type_list_indexes DbAddDel::get_choice_index(const LayoutItem_Field& from_key)
 {
   type_list_indexes result;
 
-  if(!from_key)
-    return result;
-
-  const auto from_key_name = from_key->get_name();
+  const auto from_key_name = from_key.get_name();
 
   guint index = 0;
   for(const auto& item : m_column_items)
@@ -1017,7 +1008,7 @@ DbAddDel::type_list_indexes DbAddDel::get_choice_index(const std::shared_ptr<con
     if(!field)
        continue;
 
-    const auto format = field->get_formatting_used();
+    const auto& format = field->get_formatting_used();
 
     bool choice_show_all = false;
     const auto choice_relationship =
@@ -1204,7 +1195,7 @@ DbAddDel::InnerIgnore::~InnerIgnore()
     m_pOuter->set_ignore_treeview_signals(m_bIgnoreTreeViewSignals);
   }
 
-  m_pOuter = 0;
+  m_pOuter = nullptr;
 }
 
 Gnome::Gda::Value DbAddDel::treeview_get_key(const Gtk::TreeModel::iterator& row) const
@@ -2075,7 +2066,7 @@ bool DbAddDel::start_new_record()
 
   if(fieldToEdit)
   {
-    select_item(iter, fieldToEdit, true /* start_editing */);
+    select_item(iter, *fieldToEdit, true /* start_editing */);
   }
   else
   {
@@ -2129,8 +2120,8 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
           if(primary_key_field)
           {
             //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
-            auto layout_item = std::make_shared<LayoutItem_Field>();
-            layout_item->set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
+            LayoutItem_Field layout_item;
+            layout_item.set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
 
             primary_key_value = get_value_selected(layout_item);
 
@@ -2156,7 +2147,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       }
 
       //Update the field in the record (the record with this primary key):
-      const auto field_value = get_value(row, layout_field);
+      const auto field_value = get_value(row, *layout_field);
       //std::cout << "debug: " << G_STRFUNC << ": field_value = " << field_value.to_string() << std::endl;
       //const auto field = layout_field->m_field;
       //const Glib::ustring strFieldName = layout_field->get_name();
@@ -2168,7 +2159,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       {
         //Revert to the value in the database:
         const auto value_old = get_field_value_in_database(field_in_record, window);
-        set_entered_field_data(row, layout_field, value_old);
+        set_entered_field_data(row, *layout_field, value_old);
 
         return; //The value has been reverted to the value in the database.
       }
@@ -2180,12 +2171,12 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
         //Update failed.
         //Replace with correct values.
         const auto value_old = get_field_value_in_database(field_in_record, window);
-        set_entered_field_data(row, layout_field, value_old);
+        set_entered_field_data(row, *layout_field, value_old);
       }
       else
       {
         //Display the same value in other instances of the same field:
-        set_value(row, layout_field, field_value, false /* don't set the actually-edited cell */);
+        set_value(row, *layout_field, field_value, false /* don't set the actually-edited cell */);
 
         signal_record_changed().emit();
       }
@@ -2199,7 +2190,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       {
         LayoutFieldInRecord field_in_record(layout_field, m_found_set.m_table_name /* parent */, primary_key_field, primary_key_value);
         const auto value_old = get_field_value_in_database(field_in_record, window);
-        set_entered_field_data(row, layout_field, value_old);
+        set_entered_field_data(row, *layout_field, value_old);
       }
     }
     catch(const std::exception& ex)
@@ -2211,7 +2202,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
       {
         LayoutFieldInRecord field_in_record(layout_field, m_found_set.m_table_name /* parent */, primary_key_field, primary_key_value);
         const auto value_old = get_field_value_in_database(field_in_record, window);
-        set_entered_field_data(row, layout_field, value_old);
+        set_entered_field_data(row, *layout_field, value_old);
       }
     }
   }
@@ -2273,8 +2264,8 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     //This only works when the primary key is already stored: primary_key_value = get_value_key(row);
     //primary_key_value = get_value_key_selected();
 
-    auto layout_field = std::make_shared<LayoutItem_Field>();
-    layout_field->set_full_field_details(primary_key_field);
+    LayoutItem_Field layout_field;
+    layout_field.set_full_field_details(primary_key_field);
     primary_key_value = get_value_selected(layout_field);
     std::cout << "DEBUG: get_value_key_selected(): " << primary_key_value.to_string() << std::endl;
   }
@@ -2299,7 +2290,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   {
     //Revert to a blank value.
     primary_key_value = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
-    set_entered_field_data(row, layout_field, primary_key_value);
+    set_entered_field_data(row, *layout_field, primary_key_value);
     return;
   }
 
@@ -2321,8 +2312,8 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   //If it's an auto-increment, then get the value and show it:
   if(primary_key_field->get_auto_increment())
   {
-    auto layout_item = std::make_shared<LayoutItem_Field>();
-    layout_item->set_full_field_details(primary_key_field);
+    LayoutItem_Field layout_item;
+    layout_item.set_full_field_details(primary_key_field);
     set_value(row, layout_item, primary_key_value);
   }
 
@@ -2350,18 +2341,18 @@ void DbAddDel::user_requested_delete(const Gtk::TreeModel::iterator& rowStart, c
 }
 
 //An override of the Base_DB method:
-void DbAddDel::set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void DbAddDel::set_entered_field_data(const LayoutItem_Field& field, const Gnome::Gda::Value& value)
 {
   return set_value_selected(field, value);
 }
 
 //An override of the Base_DB method:
-void DbAddDel::set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void DbAddDel::set_entered_field_data(const Gtk::TreeModel::iterator& row, const LayoutItem_Field& field, const Gnome::Gda::Value& value)
 {
   return set_value(row, field, value);
 }
 
-Gnome::Gda::Value DbAddDel::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const
+Gnome::Gda::Value DbAddDel::get_entered_field_data(const LayoutItem_Field& field) const
 {
   return get_value_selected(field);
 }
