@@ -48,8 +48,8 @@ public:
   Dialog_DefaultFormatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_DefaultFormatting();
 
-  virtual void set_field(const std::shared_ptr<const Field>& field, const Glib::ustring& table_name);
-  virtual std::shared_ptr<Field> get_field() const; //TODO_FieldShared
+  void set_field(const std::shared_ptr<const Field>& field, const Glib::ustring& table_name);
+  std::shared_ptr<Field> get_field() const; //TODO_FieldShared
 
 private:
   Gtk::Box* m_box_formatting_placeholder;
