@@ -23,6 +23,7 @@
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
 #include <glom/appwindow.h>
+#include <glom/mode_design/fields/dialog_fielddefinition.h>
 #include "../../box_db_table.h"
 #include <libglom/db_utils.h>
 //#include <libgnome/gnome-i18n.h>
@@ -279,7 +280,7 @@ void Dialog_FieldDefinition::on_combo_type_changed()
   //m_Frame_TypeDetails.remove();
 
   //Use FieldType static method to categorise field type:
- // glom_field_type fieldType = m_combo_type->get_field_type();
+ // auto fieldType = m_combo_type->get_field_type();
 
 }
 
