@@ -36,14 +36,13 @@ class ComboBox_Relationship : public Gtk::ComboBox
 {
 public:
   ComboBox_Relationship(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  virtual ~ComboBox_Relationship();
 
   typedef std::vector< std::shared_ptr<Relationship> > type_vec_relationships;
   void set_relationships(const type_vec_relationships& relationship);
 
   void set_relationships_excluding_triggered_by(const type_vec_relationships& relationship, const Glib::ustring& excluding_triggered_by_field);
 
-  void set_relationships(Document* document, const Glib::ustring parent_table_name, bool show_related_relationships = false, bool show_parent_table = true);
+  void set_relationships(const std::shared_ptr<Document>& document, const Glib::ustring parent_table_name, bool show_related_relationships = false, bool show_parent_table = true);
 
   void set_selected_relationship(const std::shared_ptr<const Relationship>& relationship);
   void set_selected_relationship(const std::shared_ptr<const Relationship>& relationship, const std::shared_ptr<const Relationship>& related_relationship);
