@@ -19,10 +19,8 @@
  */
 
 #include "dialog_field_layout.h"
-#include <libglom/data_structure/glomconversions.h>
 #include <glom/glade_utils.h>
 #include <glom/appwindow.h>
-#include <glibmm/i18n.h>
 
 namespace Glom
 {
