@@ -19,9 +19,7 @@
  */
 
 #include "dialog_copy_translation.h"
-#include <libglom/utils.h> //For bold_message()).
 #include <glom/appwindow.h>
-#include <glibmm/i18n.h>
 
 namespace Glom
 {
