@@ -291,8 +291,12 @@ void Canvas_PrintLayout::setup_context_menu()
 }
 
 
-void Canvas_PrintLayout::on_item_show_context_menu(guint button, guint32 activate_time, Glib::RefPtr<CanvasLayoutItem> item)
+void Canvas_PrintLayout::on_item_show_context_menu(GdkEventButton* event, const Glib::WeakRef<CanvasLayoutItem>& item_weak)
 {
+  const auto item = item_weak.get();
+  if(!item)
+    return;
+
   if(!m_context_menu || !item)
     return;
 
@@ -308,7 +312,7 @@ void Canvas_PrintLayout::on_item_show_context_menu(guint button, guint32 activat
 
   m_action_formatting->set_enabled(enable_formatting);
 
-  m_context_menu->popup(button, activate_time);
+  m_context_menu->popup_at_pointer((GdkEvent*)event);
 }
 
 bool Canvas_PrintLayout::on_background_button_press_event(const Glib::RefPtr<Goocanvas::Item>& /* target */, GdkEventButton* /* event */)
@@ -708,16 +712,16 @@ void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<Ca
   bool empty = true;
   if(!layoutitem_field->get_name().empty())
   {
-    const auto relationship =
-      layoutitem_field->get_relationship();
-
     if(!document)
     {
       std::cerr << G_STRFUNC << ": document is null\n";
       return;
     }
 
-    if(document->get_relationship_is_system_properties(relationship))
+    const auto relationship =
+      layoutitem_field->get_relationship();
+
+    if(relationship && document->get_relationship_is_system_properties(*relationship))
       empty = false;
   }
 
@@ -727,7 +731,7 @@ void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<Ca
     field_in_record.m_field = layoutitem_field;
     field_in_record.m_table_name = m_table_name;
     const Gnome::Gda::Value value = get_field_value_in_database(
-     field_in_record, 0 /* TODO: parent window */);
+     field_in_record, nullptr /* TODO: parent window */);
     if(!Glom::Conversions::value_is_empty(value))
     {
       canvas_item->set_db_data(value);
@@ -740,8 +744,7 @@ void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<Ca
 void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& canvas_group, const FoundSet& found_set, bool avoid_page_margins)
 {
   //A map of the text representation (e.g. field_name or relationship::field_name) to the index:
-  typedef std::map<Glib::ustring, guint> type_map_layout_fields_index;
-  type_map_layout_fields_index map_fields_index;
+  std::unordered_map<Glib::ustring, guint, std::hash<std::string>> map_fields_index;
 
   //Get list of fields to get from the database.
   SqlUtils::type_vecLayoutFields fieldsToGet;
@@ -780,7 +783,7 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
           const auto document = get_document();
           const auto from_field = DbUtils::get_fields_for_table_one_field(document,
             relationship->get_from_table(), relationship->get_from_field());
-          const Gnome::Gda::Value from_key_value = get_field_value_in_database(from_field, found_set, 0 /* TODO: window */);
+          const Gnome::Gda::Value from_key_value = get_field_value_in_database(from_field, found_set, nullptr /* TODO: window */);
           fill_with_data_portal(canvas_item, from_key_value);
         }
       }
