@@ -31,7 +31,7 @@
 #include <giomm/simpleactiongroup.h>
 
 #include <vector>
-#include <map>
+#include <unordered_map>
 
 namespace Glom
 {
@@ -40,10 +40,10 @@ class AddDelColumnInfo
 {
 public:
   AddDelColumnInfo();
-  AddDelColumnInfo(const AddDelColumnInfo& src);
-  AddDelColumnInfo(AddDelColumnInfo&& src) = delete;
-  AddDelColumnInfo& operator=(const AddDelColumnInfo& src);
-  AddDelColumnInfo& operator=(AddDelColumnInfo&& src) = delete;
+  AddDelColumnInfo(const AddDelColumnInfo& src) = default;
+  AddDelColumnInfo(AddDelColumnInfo&& src) = default;
+  AddDelColumnInfo& operator=(const AddDelColumnInfo& src) = default;
+  AddDelColumnInfo& operator=(AddDelColumnInfo&& src) = default;
 
   //If we need any more complicated style (e.g. number of decimal digits) then we will need a separate AddDelStyle class.
   enum class enumStyles
