@@ -19,12 +19,8 @@
  */
 
 #include "canvas_group_movable.h"
-#include "canvas_rect_movable.h"
-#include "canvas_line_movable.h"
-#include "canvas_text_movable.h"
 #include "libglom/utils.h"
 #include <goocanvasmm/canvas.h>
-#include <gdkmm/cursor.h>
 #include <iostream>
 
 namespace Glom
