@@ -55,7 +55,7 @@ void DialogImageSaveProgress::save(const Glib::ustring& uri)
 {
   g_assert(m_data);
 
-  if(m_data->data == 0)
+  if(m_data->data == nullptr)
     return;
 
   if(m_data->binary_length == 0)
@@ -130,7 +130,7 @@ void DialogImageSaveProgress::on_stream_write(const Glib::RefPtr<Gio::AsyncResul
 
 void DialogImageSaveProgress::error(const Glib::ustring& error_message)
 {
-  Gtk::MessageDialog dialog(*this, _("Error Saving"), Gtk::MESSAGE_ERROR);
+  Gtk::MessageDialog dialog(*this, _("Error Saving"), false, Gtk::MESSAGE_ERROR);
   dialog.set_title(_("Error saving image"));
   dialog.set_secondary_text(error_message);
 
