@@ -28,20 +28,6 @@
 namespace Glom
 {
 
-FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(const Glib::ustring& title, Gtk::FileChooserAction action, const Glib::ustring& backend)
-: Gtk::FileChooserDialog(title, action, backend),
-  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
-{
-  create_child_widgets();
-}
-
-FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(Gtk::Window& parent, const Glib::ustring& title, Gtk::FileChooserAction action, const Glib::ustring& backend)
-: Gtk::FileChooserDialog(parent, title, action, backend),
-  m_extra_widget(Gtk::ORIENTATION_VERTICAL)
-{
-  create_child_widgets();
-}
-
 FileChooserDialog_SaveExtras::FileChooserDialog_SaveExtras(const Glib::ustring& title, Gtk::FileChooserAction action)
 : Gtk::FileChooserDialog(title, action),
   m_extra_widget(Gtk::ORIENTATION_VERTICAL)
