@@ -142,12 +142,6 @@ void ImageGlom::init()
   add(m_frame);
 }
 
-
-
-ImageGlom::~ImageGlom()
-{
-}
-
 void ImageGlom::set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
 {
   LayoutWidgetField::set_layout_item(layout_item, table_name);
@@ -159,7 +153,7 @@ void ImageGlom::set_layout_item(const std::shared_ptr<LayoutItem>& layout_item,
 bool ImageGlom::on_button_press_event(GdkEventButton *button_event)
 {
   GdkModifierType mods;
-  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
 
   //Enable/Disable items.
   //We did this earlier, but get_appwindow is more likely to work now:
@@ -183,7 +177,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *button_event)
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        popup_menu(button_event->button, button_event->time);
+        popup_menu(button_event);
 
         return true; //We handled this event.
       }
@@ -195,7 +189,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *button_event)
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        popup_menu(button_event->button, button_event->time);
+        popup_menu(button_event);
 
         return true; //We handled this event.
       }
@@ -675,7 +669,7 @@ static void set_file_filter_images(Gtk::FileChooser& file_chooser)
   filter->add_pixbuf_formats();
   file_chooser.add_filter(filter);
 
-  ev_document_factory_add_filters(GTK_WIDGET(file_chooser.gobj()), 0);
+  ev_document_factory_add_filters(GTK_WIDGET(file_chooser.gobj()), nullptr);
 
   //Make Images the currently-selected one:
   file_chooser.set_filter(filter);
@@ -992,7 +986,7 @@ void ImageGlom::set_read_only(bool read_only)
   m_read_only = read_only;
 }
 
-void ImageGlom::popup_menu(guint button, guint32 activate_time)
+void ImageGlom::popup_menu(GdkEventButton* event)
 {
   if(!m_menu_popup_user_mode)
   {
@@ -1000,7 +994,7 @@ void ImageGlom::popup_menu(guint button, guint32 activate_time)
     return;
   }
 
-  m_menu_popup_user_mode->popup(button, activate_time);
+  m_menu_popup_user_mode->popup_at_pointer((GdkEvent*)event);
 
   m_action_select_file->set_enabled();
 }
