@@ -46,8 +46,7 @@ public:
   ImageGlom();
   explicit ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
-
-  virtual ~ImageGlom();
+  ~ImageGlom() override = default;
 
   void set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name) override;
 
@@ -90,7 +89,7 @@ private:
   void setup_menu_usermode();
   void show_image_data();
 
-  void popup_menu(guint button, guint32 activate_time);
+  void popup_menu(GdkEventButton* event);
 
   const GdaBinary* get_binary() const;
 
