@@ -33,11 +33,4 @@ LayoutWidgetField::type_signal_edited LayoutWidgetField::signal_edited()
   return m_signal_edited;
 }
 
-bool LayoutWidgetField::get_has_original_data() const
-{
-  //Most widgets always have the original data.
-  //Override this method for widgets that don't.
-  return true;
-}
-
 } //namespace Glom
