@@ -127,11 +127,11 @@ bool NotebookLabel::on_button_press_event(GdkEventButton *button_event)
   if(pApp && pApp->get_userlevel() == AppState::userlevels::DEVELOPER)
   {
     GdkModifierType mods;
-    gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
+    gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, nullptr, nullptr, &mods );
     if(mods & GDK_BUTTON3_MASK)
     {
       //Give user choices of actions on this item:
-      m_popup_menu->popup(button_event->button, button_event->time);
+      m_popup_menu->popup_at_pointer((GdkEvent*)button_event);
       return true; //We handled this event.
     }
   }
