@@ -19,7 +19,7 @@ void execute_func_with_date_return_value()
   Glib::ustring error_message;
   const auto value = Glom::glom_evaluate_python_function_implementation(
     Glom::Field::glom_field_type::DATE, calculation, field_values,
-    0 /* document */, "" /* table name */,
+    nullptr /* document */, "" /* table name */,
     std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
     connection,
     error_message);
@@ -57,7 +57,7 @@ void execute_func_with_date_input_value()
   Glib::ustring error_message;
   const auto value = Glom::glom_evaluate_python_function_implementation(
     Glom::Field::glom_field_type::NUMERIC, calculation, field_values,
-    0 /* document */, "" /* table name */,
+    nullptr /* document */, "" /* table name */,
     std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
     connection,
     error_message);
