@@ -105,14 +105,14 @@ int main()
   if(document->get_field(table_name, field_name_original))
   {
     std::cerr << G_STRFUNC << ": Failure: The document should have forgotten about the original field name.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Check that the new field name is known to the document:
   if(!(document->get_field(table_name, field_name_new)))
   {
     std::cerr << G_STRFUNC << ": Failure: The document does not know about the new field name.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Check that the original field name is no longer used in the relationship:
@@ -120,20 +120,20 @@ int main()
   if(!relationship)
   {
     std::cerr << G_STRFUNC << ": Failure: The relationship could not be found in the document.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   if(relationship->get_to_field() == field_name_original)
   {
     std::cerr << G_STRFUNC << ": Failure: The relationship still uses the original field name.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Check that the original field name is no longer used on a layout:
   if(field_is_on_a_layout(document, table_name, field_name_original))
   {
     std::cerr << G_STRFUNC << ": Failure: The original field name is still used on a layout.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   {
@@ -143,35 +143,44 @@ int main()
     const Glib::ustring relationship_name_new = "newrelationshipname";
     document->change_relationship_name(table_name_invoices,
       relationship_name_original, relationship_name_new);
-    if(document->get_relationship(table_name, relationship_name_original))
+    if(document->get_relationship(table_name_invoices, relationship_name_original))
     {
       std::cerr << G_STRFUNC << ": Failure: The original relationship name still exists.\n";
-      return false;
+      return EXIT_FAILURE;
     }
 
-    if(!document->get_relationship(table_name, relationship_name_new))
+    if(!document->get_relationship(table_name_invoices, relationship_name_new))
     {
       std::cerr << G_STRFUNC << ": Failure: The new relationship name does not exist.\n";
-      return false;
+      return EXIT_FAILURE;
     }
 
     //Check that the old relationship name is not used.
     auto field_on_layout =
-      get_field_on_layout(document, table_name, "contacts", "name_full");
+      get_field_on_layout(document, table_name_invoices, "contacts", "name_full");
     g_assert(field_on_layout);
     if(field_on_layout->get_relationship_name() != relationship_name_new)
     {
       std::cerr << G_STRFUNC << ": Failure: A layout item does not use the new relationship name as expected.\n";
-      return false;
+      return EXIT_FAILURE;
     }
   }
 
   //Remove a field from the whole document:
   document->remove_field("publisher", "publisher_id");
+
+  //Check that the old field name is not used.
+  auto field =
+    document->get_field("publisher", "publisher_id");
+  if (field) {
+    std::cerr << G_STRFUNC << ": Failure: The removed field name still exists.\n";
+    return EXIT_FAILURE;
+  }
+
   if(field_is_on_a_layout(document, "publisher", "publisher_id"))
   {
     std::cerr << G_STRFUNC << ": Failure: The removed field name is still used on a layout.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Remove a relationship:
@@ -180,7 +189,7 @@ int main()
   if(relationship)
   {
     std::cerr << G_STRFUNC << ": Failure: The removed relationship still exists.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Change a table name:
@@ -189,27 +198,27 @@ int main()
   if(document->get_table("invoice_lines"))
   {
     std::cerr << G_STRFUNC << ": Failure: The renamed table still exists.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   relationship = document->get_relationship("invoices", "invoice_lines");
   if(!relationship)
   {
     std::cerr << G_STRFUNC << ": Failure: The expected relationship does not exist.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   if(relationship->get_to_table() != table_renamed)
   {
     std::cerr << G_STRFUNC << ": Failure: The relationship's to_table does have been renamed.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   document->remove_table("products");
   if(document->get_table("products"))
   {
     std::cerr << G_STRFUNC << ": Failure: The removed table still exists.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
 
@@ -219,7 +228,7 @@ int main()
   if(!print_layout)
   {
     std::cerr << G_STRFUNC << ": Failure: Could not get an expected print layout.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   document->remove_print_layout("contacts", "contact_details");
@@ -228,7 +237,7 @@ int main()
   if(print_layout)
   {
     std::cerr << G_STRFUNC << ": Failure: The removed print layotu still exists.\n";
-    return false;
+    return EXIT_FAILURE;
   }
 
   //Test user groups:
