@@ -26,9 +26,9 @@
 static
 bool test_compare_empty_instances()
 {
-  auto layout_item1 = std::make_shared<Glom::LayoutItem_Field>();
-  auto layout_item2 = std::make_shared<Glom::LayoutItem_Field>();
-  if(!layout_item1->is_same_field(layout_item2))
+  Glom::LayoutItem_Field layout_item1;
+  Glom::LayoutItem_Field layout_item2;
+  if(!layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with empty instances.\n";
     return false;
@@ -40,11 +40,11 @@ bool test_compare_empty_instances()
 static
 bool test_compare_same_named_instances()
 {
-  auto layout_item1 = std::make_shared<Glom::LayoutItem_Field>();
-  auto layout_item2 = std::make_shared<Glom::LayoutItem_Field>();
-  layout_item1->set_name("one");
-  layout_item2->set_name("two");
-  if(layout_item1->is_same_field(layout_item2))
+  Glom::LayoutItem_Field layout_item1;
+  Glom::LayoutItem_Field layout_item2;
+  layout_item1.set_name("one");
+  layout_item2.set_name("two");
+  if(layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with named field instances.\n";
     return false;
@@ -56,12 +56,12 @@ bool test_compare_same_named_instances()
 static
 bool test_compare_same_named_instances_unrelated_differences()
 {
-  auto layout_item1 = std::make_shared<Glom::LayoutItem_Field>();
-  auto layout_item2 = std::make_shared<Glom::LayoutItem_Field>();
-  layout_item1->set_name("one");
-  layout_item2->set_name("one");
-  layout_item2->set_hidden(); //is_same_field() should ignore this.
-  if(!layout_item1->is_same_field(layout_item2))
+  Glom::LayoutItem_Field layout_item1;
+  Glom::LayoutItem_Field layout_item2;
+  layout_item1.set_name("one");
+  layout_item2.set_name("one");
+  layout_item2.set_hidden(); //is_same_field() should ignore this.
+  if(!layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with named field instances with unrelated differences.\n";
     return false;
@@ -74,27 +74,27 @@ bool test_compare_same_named_instances_unrelated_differences()
 static
 bool test_compare_same_named_instances_with_relationship()
 {
-  auto layout_item1 = std::make_shared<Glom::LayoutItem_Field>();
-  auto layout_item2 = std::make_shared<Glom::LayoutItem_Field>();
-  layout_item1->set_name("one");
-  layout_item2->set_name("one");
+  Glom::LayoutItem_Field layout_item1;
+  Glom::LayoutItem_Field layout_item2;
+  layout_item1.set_name("one");
+  layout_item2.set_name("one");
 
   auto relationship1 = std::make_shared<Glom::Relationship>();
   relationship1->set_name("relationship1");
-  layout_item1->set_relationship(relationship1);
+  layout_item1.set_relationship(relationship1);
 
   auto relationship2 = std::make_shared<Glom::Relationship>();
   relationship2->set_name("relationship2");
-  layout_item2->set_relationship(relationship2);
+  layout_item2.set_relationship(relationship2);
 
-  if(layout_item1->is_same_field(layout_item2))
+  if(layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with field instances with different relationships.\n";
     return false;
   }
 
-  layout_item2->set_relationship(relationship1);
-  if(!layout_item1->is_same_field(layout_item2))
+  layout_item2.set_relationship(relationship1);
+  if(!layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with field instances with same relationships.\n";
     return false;
@@ -106,21 +106,21 @@ bool test_compare_same_named_instances_with_relationship()
 static
 bool test_compare_same_named_instances_with_related_relationship()
 {
-  auto layout_item1 = std::make_shared<Glom::LayoutItem_Field>();
-  auto layout_item2 = std::make_shared<Glom::LayoutItem_Field>();
-  layout_item1->set_name("one");
-  layout_item2->set_name("one");
+  Glom::LayoutItem_Field layout_item1;
+  Glom::LayoutItem_Field layout_item2;
+  layout_item1.set_name("one");
+  layout_item2.set_name("one");
 
   auto relationship1 = std::make_shared<Glom::Relationship>();
   relationship1->set_name("relationship1");
-  layout_item1->set_relationship(relationship1);
-  layout_item2->set_relationship(relationship1);
+  layout_item1.set_relationship(relationship1);
+  layout_item2.set_relationship(relationship1);
 
   auto relationship_related1 = std::make_shared<Glom::Relationship>();
   relationship_related1->set_name("relationship_related1");
-  layout_item1->set_related_relationship(relationship_related1);
+  layout_item1.set_related_relationship(relationship_related1);
 
-  if(layout_item1->is_same_field(layout_item2))
+  if(layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with field instances with different (one unset) related relationships.\n";
     return false;
@@ -128,16 +128,16 @@ bool test_compare_same_named_instances_with_related_relationship()
 
   auto relationship_related2 = std::make_shared<Glom::Relationship>();
   relationship_related2->set_name("relationship_related2");
-  layout_item2->set_related_relationship(relationship_related2);
+  layout_item2.set_related_relationship(relationship_related2);
 
-  if(layout_item1->is_same_field(layout_item2))
+  if(layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with field instances with different related relationships.\n";
     return false;
   }
 
-  layout_item2->set_related_relationship(relationship_related1);
-  if(!layout_item1->is_same_field(layout_item2))
+  layout_item2.set_related_relationship(relationship_related1);
+  if(!layout_item1.is_same_field(layout_item2))
   {
     std::cerr << G_STRFUNC << ": Glom::LayoutItem_Field::is_same_field() failed with field instances with same related relationships.\n";
     return false;
