@@ -22,8 +22,8 @@ void on_reemit_int(int param)
 int main()
 {
   {
-    sigc::signal<void> signal_first_emit;
-    sigc::signal<void> signal_to_reemit;
+    sigc::signal<void()> signal_first_emit;
+    sigc::signal<void()> signal_to_reemit;
 
     Glom::signal_connect_for_reemit_0args(signal_first_emit, signal_to_reemit);
     signal_to_reemit.connect( sigc::ptr_fun(&on_reemit_void) );
@@ -32,8 +32,8 @@ int main()
   }
 
   {
-    sigc::signal<void, int> signal_first_emit;
-    sigc::signal<void, int> signal_to_reemit;
+    sigc::signal<void(int)> signal_first_emit;
+    sigc::signal<void(int)> signal_to_reemit;
 
     Glom::signal_connect_for_reemit_1arg(signal_first_emit, signal_to_reemit);
     signal_to_reemit.connect( sigc::ptr_fun(&on_reemit_int) );
